@@ -2,23 +2,32 @@
 
 import os
 import time
-
-import warnings
-
 import urllib
-import requests
+import warnings
 
 import numpy as np
 import pandas as pd
+import requests
 
 from jpy_datareader.base import _BaseReader
 
-
 _version = "3.0"
 _BASE_URL = f"https://api.e-stat.go.jp/rest/{_version}/app/json"
 
-attrdict = {"code": "コード", "name": "名", "level": "階層レベル", "unit": "単位", "parentCode": "親コード", "addInf": "追加情報",
-            "tab": "表章項目", "cat": "分類", "area": "地域", "time": "時間軸", "anotation": "注釈記号"}
+attrdict = {
+    "code": "コード",
+    "name": "名",
+    "level": "階層レベル",
+    "unit": "単位",
+    "parentCode": "親コード",
+    "addInf": "追加情報",
+    "tab": "表章項目",
+    "cat": "分類",
+    "area": "地域",
+    "time": "時間軸",
+    "anotation": "注釈記号",
+}
+
 
 class _eStatReader(_BaseReader):
     """
@@ -65,20 +74,26 @@ class _eStatReader(_BaseReader):
     @property
     def url(self, path="getStatsList"):
         """API URL"""
-        if path not in ["getStatsList", "getDataCatalog", "getMetaInfo", "getStatsData"]:
+        if path not in [
+            "getStatsList",
+            "getDataCatalog",
+            "getMetaInfo",
+            "getStatsData",
+        ]:
             path = "getStatsList"
-            print("pathはgetStatsList, getDataCatalog, getMetaInfo, getStatsDataで指定します。pathをgetStatsListに置換しました。")
-        eStat_URL = _BASE_URL + "/{path}?"
+            print(
+                "pathはgetStatsList, getDataCatalog, getMetaInfo, getStatsDataで指定します。pathをgetStatsListに置換しました。"
+            )
+        eStat_URL = _BASE_URL + f"/{path}?"
         return eStat_URL
 
-
     @property
     def params(self):
         """Parameters to use in API calls"""
         pdict = {
             "appId": self.sapi_key,
         }
-    
+
         params = {
             "api_key": self.api_key,
         }
@@ -95,8 +110,8 @@ class _eStatReader(_BaseReader):
         df.columns = cols
         return df
 
-class StatsListReader(_eStatReader):
 
+class StatsListReader(_eStatReader):
     def __init__(
         self,
         api_key,
@@ -105,17 +120,17 @@ class StatsListReader(_eStatReader):
         pause=0.1,
         timeout=300,
         session=None,
-        surveyYears=None, 
-        openYears=None, 
-        statsField=None, 
-        statsCode=None, 
-        searchWord=None, 
-        searchKind=None, 
-        collectArea=None, 
-        statsNameList=None, 
-        startPosition=None, 
-        limit=None, 
-        updatedDate=None, 
+        surveyYears=None,
+        openYears=None,
+        statsField=None,
+        statsCode=None,
+        searchWord=None,
+        searchKind=None,
+        collectArea=None,
+        statsNameList=None,
+        startPosition=None,
+        limit=None,
+        updatedDate=None,
     ):
 
         super().__init__(
@@ -162,7 +177,7 @@ class StatsListReader(_eStatReader):
         pdict = {
             "appId": self.api_key,
         }
-        
+
         if isinstance(self.surveyYears, (str, int)):
             pdict.update({"surveyYears": self.surveyYears})
         if isinstance(self.surveyYears, (str, int)):
@@ -189,7 +204,7 @@ class StatsListReader(_eStatReader):
             pdict.update({"limit": self.limit})
         if isinstance(self.updatedDate, (str, int)):
             pdict.update({"updatedDate": self.updatedDate})
-        
+
         return pdict
 
     def read(self):
@@ -202,7 +217,7 @@ class StatsListReader(_eStatReader):
     def _read_one_data(self, url, params):
         """read one data from specified URL"""
         out = self._get_response(url, params=params).json()
-        
+
         if "RESULT" in out["GET_STATS_LIST"].keys():
             if "STATUS" in out["GET_STATS_LIST"]["RESULT"].keys():
                 self.STATUS = out["GET_STATS_LIST"]["RESULT"]["STATUS"]
@@ -221,26 +236,41 @@ class StatsListReader(_eStatReader):
             if "NUMBER" in out["GET_STATS_LIST"]["DATALIST_INF"].keys():
                 self.NUMBER = out["GET_STATS_LIST"]["DATALIST_INF"]["NUMBER"]
             if "RESULT_INF" in out["GET_STATS_LIST"]["DATALIST_INF"].keys():
-                if "FROM_NUMBER" in  out["GET_STATS_LIST"]["DATALIST_INF"]["RESULT_INF"].keys():
+                if (
+                    "FROM_NUMBER"
+                    in out["GET_STATS_LIST"]["DATALIST_INF"]["RESULT_INF"].keys()
+                ):
                     self.FROM_NUMBER = out["GET_STATS_LIST"]["DATALIST_INF"]["RESULT_INF"]["FROM_NUMBER"]
-                if "TO_NUMBER" in  out["GET_STATS_LIST"]["DATALIST_INF"]["RESULT_INF"].keys():
+                if (
+                    "TO_NUMBER"
+                    in out["GET_STATS_LIST"]["DATALIST_INF"]["RESULT_INF"].keys()
+                ):
                     self.TO_NUMBER = out["GET_STATS_LIST"]["DATALIST_INF"]["RESULT_INF"]["TO_NUMBER"]
-                if "NEXT_KEY" in out["GET_STATS_LIST"]["DATALIST_INF"]["RESULT_INF"].keys():
+                if (
+                    "NEXT_KEY"
+                    in out["GET_STATS_LIST"]["DATALIST_INF"]["RESULT_INF"].keys()
+                ):
                     self.NEXT_KEY = out["GET_STATS_LIST"]["DATALIST_INF"]["RESULT_INF"]["NEXT_KEY"]
 
-        TABLE_INF = pd.json_normalize(out, record_path=["GET_STATS_LIST", "DATALIST_INF", "TABLE_INF"], sep="_")
-        TABLE_INF.columns = list(map(lambda x: x.replace("@", "").rstrip("_$"), TABLE_INF.columns.values.tolist()))
+        TABLE_INF = pd.json_normalize(
+            out, record_path=["GET_STATS_LIST", "DATALIST_INF", "TABLE_INF"], sep="_"
+        )
+        TABLE_INF.columns = list(
+            map(
+                lambda x: x.replace("@", "").rstrip("_$"),
+                TABLE_INF.columns.values.tolist(),
+            )
+        )
 
         return TABLE_INF
 
 
 class MetaInfoReader(_eStatReader):
-
     def __init__(
         self,
         api_key,
-        statsDataId="",
-        header="name",
+        statsDataId,
+        name_or_id="name",
         lvhierarchy=False,
         lvfillna=False,
         explanationGetFlg=None,
@@ -270,7 +300,7 @@ class MetaInfoReader(_eStatReader):
 
         self.api_key = api_key
         self.statsDataId = statsDataId
-        self.header = header
+        self.name_or_id = name_or_id
         self.lvhierarchy = lvhierarchy
         self.lvfillna = lvfillna
         self.explanationGetFlg = explanationGetFlg
@@ -287,7 +317,7 @@ class MetaInfoReader(_eStatReader):
         pdict = {
             "appId": self.api_key,
         }
-        
+
         if isinstance(self.statsDataId, (str, int)):
             pdict.update({"statsDataId": self.statsDataId})
         if self.explanationGetFlg in ["Y", "N"]:
@@ -309,13 +339,13 @@ class MetaInfoReader(_eStatReader):
         self.STATUS = out["GET_META_INFO"]["RESULT"]["STATUS"]
         self.ERROR_MSG = out["GET_META_INFO"]["RESULT"]["ERROR_MSG"]
         self.DATE = out["GET_META_INFO"]["RESULT"]["DATE"]
-        if "PARAMETER" in out['GET_META_INFO'].keys():
-            if "LANG"  in out['GET_META_INFO']["PARAMETER"].keys():
+        if "PARAMETER" in out["GET_META_INFO"].keys():
+            if "LANG" in out["GET_META_INFO"]["PARAMETER"].keys():
                 self.LANG = out["GET_META_INFO"]["PARAMETER"]["LANG"]
-            if "DATA_FORMAT"  in out['GET_META_INFO']["PARAMETER"].keys():
+            if "DATA_FORMAT" in out["GET_META_INFO"]["PARAMETER"].keys():
                 self.DATA_FORMAT = out["GET_META_INFO"]["PARAMETER"]["DATA_FORMAT"]
-        if "METADATA_INF" in out['GET_META_INFO'].keys():
-            if "TABLE_INF" in out['GET_META_INFO']["METADATA_INF"].keys():
+        if "METADATA_INF" in out["GET_META_INFO"].keys():
+            if "TABLE_INF" in out["GET_META_INFO"]["METADATA_INF"].keys():
                 self.TABLE_INF = out["GET_META_INFO"]["METADATA_INF"]["TABLE_INF"]
                 if "STAT_NAME" in self.TABLE_INF.keys():
                     self.STAT_NAME = self.TABLE_INF["STAT_NAME"]
@@ -346,7 +376,9 @@ class MetaInfoReader(_eStatReader):
                 if "STATISTICS_NAME_SPEC" in self.TABLE_INF.keys():
                     self.STATISTICS_NAME_SPEC = self.TABLE_INF["STATISTICS_NAME_SPEC"]
                 if "TABULATION_SUB_CATEGORY1" in self.TABLE_INF.keys():
-                    self.TABULATION_SUB_CATEGORY1 = self.TABLE_INF["TABULATION_SUB_CATEGORY1"]
+                    self.TABULATION_SUB_CATEGORY1 = self.TABLE_INF[
+                        "TABULATION_SUB_CATEGORY1"
+                    ]
                 if "DESCRIPTION" in self.TABLE_INF.keys():
                     self.DESCRIPTION = self.TABLE_INF["DESCRIPTION"]
                 if "TITLE_SPEC" in self.TABLE_INF.keys():
@@ -364,22 +396,30 @@ class MetaInfoReader(_eStatReader):
                     CLASS = pd.DataFrame(pd.Series(co["CLASS"])).T
                 else:
                     print(co["@name"] + "はlist型でもdict型でもありません。")
-                CLASS.columns = list(map(lambda x: x.lstrip("@"), CLASS.columns.values.tolist()))
+                CLASS.columns = list(
+                    map(lambda x: x.lstrip("@"), CLASS.columns.values.tolist())
+                )
 
-                is_hierarchy = self.lvhierarchy & (len(CLASS['level'].unique()) > 1)
+                is_hierarchy = self.lvhierarchy & (len(CLASS["level"].unique()) > 1)
                 if is_hierarchy:
-                    levels = self.hierarchy_level(CLASS, co['@id'])
+                    levels = self.hierarchy_level(CLASS, co["@id"])
 
-                if self.header == "name":
-                    CLASS.columns = list(map(lambda x: co["@name"] + x, CLASS.columns.values.tolist()))
+                if self.name_or_id == "name":
+                    CLASS.columns = list(
+                        map(lambda x: co["@name"] + x, CLASS.columns.values.tolist())
+                    )
                     CLASS = self.rename_japanese(CLASS)
                 else:
-                    CLASS.columns = list(map(lambda x: co["@id"] + "_" + x, CLASS.columns.values.tolist()))
+                    CLASS.columns = list(
+                        map(
+                            lambda x: co["@id"] + "_" + x, CLASS.columns.values.tolist()
+                        )
+                    )
 
                 if is_hierarchy:
-                    dfs[co['@id']] = [CLASS, levels]
+                    dfs[co["@id"]] = [CLASS, levels]
                 else:
-                    dfs[co['@id']] = CLASS
+                    dfs[co["@id"]] = CLASS
 
         else:
             print("CLASS_OBJはlist型ではありません。")
@@ -387,15 +427,17 @@ class MetaInfoReader(_eStatReader):
         return dfs
 
     def hierarchy_level(self, df, id):
-        levels = df[df["level"]=='1'][["code"]]
+        levels = df[df["level"] == "1"][["code"]]
         levels.columns = ["level1"]
         for lv in np.sort(df["level"].unique().astype(int))[1:]:
-            child = df[df["level"]==str(lv)][["parentCode", "code"]]
-            child.columns = ["level"+str(lv-1), "level"+str(lv)]
-            levels = levels.merge(child, on="level"+str(lv-1), how="left")
+            child = df[df["level"] == str(lv)][["parentCode", "code"]]
+            child.columns = ["level" + str(lv - 1), "level" + str(lv)]
+            levels = levels.merge(child, on="level" + str(lv - 1), how="left")
         if self.lvfillna:
             levels = levels.fillna(method="ffill", axis=1)
-        levels.columns = list(map(lambda x: id + "_" + x, levels.columns.values.tolist()))
+        levels.columns = list(
+            map(lambda x: id + "_" + x, levels.columns.values.tolist())
+        )
         return levels
 
 
@@ -410,46 +452,46 @@ class StatsDataReader(_eStatReader):
     api_key : str, optional
         eStat API key.
         取得したアプリケーションID(appId)を指定.
-    header : "name" or "id"
+    name_or_id : "name" or "id"
     """
 
     def __init__(
         self,
         api_key,
-        header="name",
+        statsDataId,
+        name_or_id="name",
         explanationGetFlg=None,
         retry_count=3,
         pause=0.1,
         timeout=30,
         session=None,
-        statsDataId="", 
-        lvTab=None, 
-        cdTab=None, 
-        cdTabFrom=None, 
-        cdTabTo=None, 
-        lvTime=None, 
-        cdTime=None, 
-        cdTimeFrom=None, 
-        cdTimeTo=None, 
-        lvArea=None, 
-        cdArea=None, 
-        cdAreaFrom=None, 
-        cdAreaTo=None, 
-        lvCat01=None, 
-        cdCat01=None, 
-        cdCat01From=None, 
-        cdCat01To=None, 
-        lvCat02=None, 
-        cdCat02=None, 
-        cdCat02From=None, 
-        cdCat02To=None, 
-        lvCat03=None, 
-        cdCat03=None, 
-        cdCat03From=None, 
-        cdCat03To=None, 
-        startPosition=None, 
-        limit=100000, 
-        metaGetFlg=None, 
+        lvTab=None,
+        cdTab=None,
+        cdTabFrom=None,
+        cdTabTo=None,
+        lvTime=None,
+        cdTime=None,
+        cdTimeFrom=None,
+        cdTimeTo=None,
+        lvArea=None,
+        cdArea=None,
+        cdAreaFrom=None,
+        cdAreaTo=None,
+        lvCat01=None,
+        cdCat01=None,
+        cdCat01From=None,
+        cdCat01To=None,
+        lvCat02=None,
+        cdCat02=None,
+        cdCat02From=None,
+        cdCat02To=None,
+        lvCat03=None,
+        cdCat03=None,
+        cdCat03From=None,
+        cdCat03To=None,
+        startPosition=None,
+        limit=100000,
+        metaGetFlg=None,
         cntGetFlg=None,
         annotationGetFlg=None,
         replaceSpChar=2,
@@ -475,7 +517,7 @@ class StatsDataReader(_eStatReader):
             )
 
         self.api_key = api_key
-        self.header = header
+        self.name_or_id = name_or_id
         self.statsDataId = statsDataId
         self.lvTab = lvTab
         self.cdTab = cdTab
@@ -522,7 +564,7 @@ class StatsDataReader(_eStatReader):
         pdict = {
             "appId": self.api_key,
         }
-        
+
         if isinstance(self.statsDataId, (str, int)):
             pdict.update({"statsDataId": self.statsDataId})
         # 表章事項
@@ -594,7 +636,6 @@ class StatsDataReader(_eStatReader):
             pdict.update({"annotationGetFlg": self.annotationGetFlg})
         if self.replaceSpChar in range(4):
             pdict.update({"replaceSpChar": self.replaceSpChar})
-        
         return pdict
 
     def read(self, normal=True, split_units=False):
@@ -604,16 +645,53 @@ class StatsDataReader(_eStatReader):
             if normal:
                 return data
             else:
-                def denormalization(df, header):
+
+                def denormalization(input, header):
                     if header == "name":
-                        df = df.drop([c for c in df.columns if (('コード' in c)|('階層レベル' in c)|('unit' in c)|('単位' in c)|('親コード' in c)|('追加情報' in c))], axis=1)
-                        df = df.set_index([c for c in df.columns if "名" in c]).unstack(self.tabcol)
+                        df = input.drop(
+                            [
+                                c
+                                for c in input.columns
+                                if (
+                                    ("コード" in c)
+                                    | ("階層レベル" in c)
+                                    | ("unit" in c)
+                                    | ("単位" in c)
+                                    | ("親コード" in c)
+                                    | ("追加情報" in c)
+                                )
+                            ],
+                            axis=1,
+                        )
+                        df = df.set_index([c for c in df.columns if "名" in c]).unstack(
+                            self.tabcol
+                        )
                     else:
-                        df = df.drop([c for c in df.columns if (('code' in c)|('level' in c)|('unit' in c)|('parentCode' in c)|('addInf' in c))], axis=1)
-                        df = df.set_index([c for c in df.columns if "name" in c]).unstack(self.tabcol)
+                        df = df.drop(
+                            [
+                                c
+                                for c in input.columns
+                                if (
+                                    ("code" in c)
+                                    | ("level" in c)
+                                    | ("unit" in c)
+                                    | ("parentCode" in c)
+                                    | ("addInf" in c)
+                                )
+                            ],
+                            axis=1,
+                        )
+                        df = df.set_index(
+                            [c for c in df.columns if "name" in c]
+                        ).unstack(self.tabcol)
                     df.columns = [l2 for l1, l2 in df.columns]
                     df = df.reset_index()
-                    df.columns = list(map(lambda x: x.replace("_name", "").rstrip("名"), df.columns.values.tolist()))
+                    df.columns = list(
+                        map(
+                            lambda x: x.replace("_name", "").rstrip("名"),
+                            df.columns.values.tolist(),
+                        )
+                    )
                     return df
 
                 if split_units:
@@ -626,11 +704,11 @@ class StatsDataReader(_eStatReader):
 
                     datasets = {}
                     for u in data["unit"].unique():
-                        df = data[data["unit"]==u]
-                        datasets[u] = denormalization(df, self.header)
+                        df = data[data["unit"] == u]
+                        datasets[u] = denormalization(df, self.name_or_id)
                     return datasets
                 else:
-                    return denormalization(data, self.header)
+                    return denormalization(data, self.name_or_id)
 
         finally:
             self.close()
@@ -641,23 +719,41 @@ class StatsDataReader(_eStatReader):
             OVERALL_TOTAL_NUMBER = out["GET_STATS_DATA"]["STATISTICAL_DATA"]["TABLE_INF"]["OVERALL_TOTAL_NUMBER"]
 
             if OVERALL_TOTAL_NUMBER > 100000:
-                ptrans = {"tab": "cdTab",
+                ptrans = {
+                    "tab": "cdTab",
                     "time": "cdTime",
                     "area": "cdArea",
-                    "cat01": "cdCat01", 
+                    "cat01": "cdCat01",
                     "cat02": "cdCat02",
                     "cat03": "cdCat03",
-                    "cat04": "cdCat04"}
+                    "cat04": "cdCat04",
+                }
+
+                cls = pd.DataFrame(
+                    [
+                        [n, co["@id"], len(co["CLASS"])]
+                        for n, co in enumerate(
+                            out["GET_STATS_DATA"]["STATISTICAL_DATA"]["CLASS_INF"][
+                                "CLASS_OBJ"
+                            ]
+                        )
+                        if isinstance(co["CLASS"], list)
+                    ]
+                ).sort_values(2, ascending=False)
 
-                cls = pd.DataFrame([[n, co["@id"], len(co["CLASS"])] for n, co in enumerate(out["GET_STATS_DATA"]["STATISTICAL_DATA"]["CLASS_INF"]["CLASS_OBJ"]) if isinstance(co["CLASS"], list)]).sort_values(2, ascending=False)
- 
                 param_names = []
                 codes = []
                 tn = OVERALL_TOTAL_NUMBER
                 for i in range(len(cls)):
                     param_names += [ptrans[cls.iloc[i, 1]]]
-                    codes.append(list(pd.DataFrame(out["GET_STATS_DATA"]["STATISTICAL_DATA"]["CLASS_INF"]["CLASS_OBJ"][cls.iloc[i, 0]]["CLASS"])["@code"]))
-                    tn //=  cls.iloc[i, 2]
+                    codes.append(
+                        list(
+                            pd.DataFrame(
+                                out["GET_STATS_DATA"]["STATISTICAL_DATA"]["CLASS_INF"]["CLASS_OBJ"][cls.iloc[i, 0]]["CLASS"]
+                            )["@code"]
+                        )
+                    )
+                    tn //= cls.iloc[i, 2]
                     if tn < 100000:
                         break
 
@@ -665,7 +761,7 @@ class StatsDataReader(_eStatReader):
                 pools = [tuple(pool) for pool in codes]
                 result = [[]]
                 for pool in pools:
-                    result = [x+[y] for x in result for y in pool]
+                    result = [x + [y] for x in result for y in pool]
                 for prod in result:
                     codes_product += [tuple(prod)]
 
@@ -696,8 +792,12 @@ class StatsDataReader(_eStatReader):
             if "DATE" in out["GET_STATS_DATA"]["RESULT"].keys():
                 self.DATE = out["GET_STATS_DATA"]["RESULT"]["DATE"]
 
-        VALUE = pd.DataFrame(out["GET_STATS_DATA"]["STATISTICAL_DATA"]["DATA_INF"]["VALUE"])
-        self.attrlist = list(map(lambda x: x.lstrip("@"), VALUE.columns.values.tolist()))
+        VALUE = pd.DataFrame(
+            out["GET_STATS_DATA"]["STATISTICAL_DATA"]["DATA_INF"]["VALUE"]
+        )
+        self.attrlist = list(
+            map(lambda x: x.lstrip("@"), VALUE.columns.values.tolist())
+        )
         VALUE.columns = self.attrlist
 
         if "PARAMETER" in out["GET_STATS_DATA"].keys():
@@ -706,17 +806,34 @@ class StatsDataReader(_eStatReader):
             if "DATA_FORMAT" in out["GET_STATS_DATA"]["PARAMETER"].keys():
                 self.DATA_FORMAT = out["GET_STATS_DATA"]["PARAMETER"]["DATA_FORMAT"]
             if "START_POSITION" in out["GET_STATS_DATA"]["PARAMETER"].keys():
-                self.START_POSITION = out["GET_STATS_DATA"]["PARAMETER"]["START_POSITION"]
+                self.START_POSITION = out["GET_STATS_DATA"]["PARAMETER"][
+                    "START_POSITION"
+                ]
             if "METAGET_FLG" in out["GET_STATS_DATA"]["PARAMETER"].keys():
-                self.METAGET_FLG = out["GET_STATS_DATA"]["PARAMETER"]["METAGET_FLG"]        
+                self.METAGET_FLG = out["GET_STATS_DATA"]["PARAMETER"]["METAGET_FLG"]
         if "STATISTICAL_DATA" in out["GET_STATS_DATA"].keys():
             if "RESULT_INF" in out["GET_STATS_DATA"]["STATISTICAL_DATA"].keys():
-                if "TOTAL_NUMBER" in out["GET_STATS_DATA"]["STATISTICAL_DATA"]["RESULT_INF"].keys():
-                    self.TOTAL_NUMBER = out["GET_STATS_DATA"]["STATISTICAL_DATA"]["RESULT_INF"]["TOTAL_NUMBER"]
-                if "FROM_NUMBER" in out["GET_STATS_DATA"]["STATISTICAL_DATA"]["RESULT_INF"].keys():
-                    self.FROM_NUMBER = out["GET_STATS_DATA"]["STATISTICAL_DATA"]["RESULT_INF"]["FROM_NUMBER"]
-                if "TO_NUMBER" in out["GET_STATS_DATA"]["STATISTICAL_DATA"]["RESULT_INF"].keys():
-                    self.TO_NUMBER = out["GET_STATS_DATA"]["STATISTICAL_DATA"]["RESULT_INF"]["TO_NUMBER"]
+                if (
+                    "TOTAL_NUMBER"
+                    in out["GET_STATS_DATA"]["STATISTICAL_DATA"]["RESULT_INF"].keys()
+                ):
+                    self.TOTAL_NUMBER = out["GET_STATS_DATA"]["STATISTICAL_DATA"][
+                        "RESULT_INF"
+                    ]["TOTAL_NUMBER"]
+                if (
+                    "FROM_NUMBER"
+                    in out["GET_STATS_DATA"]["STATISTICAL_DATA"]["RESULT_INF"].keys()
+                ):
+                    self.FROM_NUMBER = out["GET_STATS_DATA"]["STATISTICAL_DATA"][
+                        "RESULT_INF"
+                    ]["FROM_NUMBER"]
+                if (
+                    "TO_NUMBER"
+                    in out["GET_STATS_DATA"]["STATISTICAL_DATA"]["RESULT_INF"].keys()
+                ):
+                    self.TO_NUMBER = out["GET_STATS_DATA"]["STATISTICAL_DATA"][
+                        "RESULT_INF"
+                    ]["TO_NUMBER"]
             if "TABLE_INF" in out["GET_STATS_DATA"]["STATISTICAL_DATA"].keys():
                 self.TABLE_INF = out["GET_STATS_DATA"]["STATISTICAL_DATA"]["TABLE_INF"]
                 if "STATISTICS_NAME" in self.TABLE_INF.keys():
@@ -726,8 +843,13 @@ class StatsDataReader(_eStatReader):
                 if "OVERALL_TOTAL_NUMBER" in self.TABLE_INF.keys():
                     self.OVERALL_TOTAL_NUMBER = self.TABLE_INF["OVERALL_TOTAL_NUMBER"]
             if "DATA_INF" in out["GET_STATS_DATA"]["STATISTICAL_DATA"].keys():
-                if "NOTE" in out["GET_STATS_DATA"]["STATISTICAL_DATA"]["DATA_INF"].keys():
-                    self.NOTE = out["GET_STATS_DATA"]["STATISTICAL_DATA"]["DATA_INF"]["NOTE"]
+                if (
+                    "NOTE"
+                    in out["GET_STATS_DATA"]["STATISTICAL_DATA"]["DATA_INF"].keys()
+                ):
+                    self.NOTE = out["GET_STATS_DATA"]["STATISTICAL_DATA"]["DATA_INF"][
+                        "NOTE"
+                    ]
                     if isinstance(self.NOTE, list):
                         note_char = [n["@char"] for n in self.NOTE]
                         VALUE["$"] = VALUE["$"].replace(note_char, self.na_values)
@@ -735,7 +857,7 @@ class StatsDataReader(_eStatReader):
                         note_char = self.NOTE["@char"]
                         VALUE["$"] = VALUE["$"].replace(note_char, self.na_values)
                     if np.isnan(self.na_values):
-                        VALUE["$"] =  VALUE["$"].astype(float)
+                        VALUE["$"] = VALUE["$"].astype(float)
 
         CLASS_OBJ = out["GET_STATS_DATA"]["STATISTICAL_DATA"]["CLASS_INF"]["CLASS_OBJ"]
         if isinstance(CLASS_OBJ, list):
@@ -748,38 +870,63 @@ class StatsDataReader(_eStatReader):
                 else:
                     continue
                 CLASS = CLASS.set_index("@code")
-                if self.header == "id":
-                    CLASS.columns = list(map(lambda x: co["@id"] + "_" + x.lstrip("@"), CLASS.columns.values.tolist()))
+                if self.name_or_id == "id":
+                    CLASS.columns = list(
+                        map(
+                            lambda x: co["@id"] + "_" + x.lstrip("@"),
+                            CLASS.columns.values.tolist(),
+                        )
+                    )
                     self.tabcol = "tab_name"
-                    VALUE = VALUE.merge(CLASS, left_on=co["@id"], right_index=True, how="left")
+                    VALUE = VALUE.merge(
+                        CLASS, left_on=co["@id"], right_index=True, how="left"
+                    )
                 else:
-                    CLASS.columns = list(map(lambda x: co["@name"] + x.lstrip("@"), CLASS.columns.values.tolist()))
+                    CLASS.columns = list(
+                        map(
+                            lambda x: co["@name"] + x.lstrip("@"),
+                            CLASS.columns.values.tolist(),
+                        )
+                    )
                     self.tabcol = "表章項目名"
-                    VALUE = VALUE.merge(CLASS, left_on=co["@id"], right_index=True, how="left")
+                    VALUE = VALUE.merge(
+                        CLASS, left_on=co["@id"], right_index=True, how="left"
+                    )
         else:
             print("CLASS_OBJはlist型ではありません。")
 
-        VALUE.columns = VALUE.columns = [c + "_code" if c in self.attrlist else c for c in VALUE.columns ]
+        VALUE.columns = VALUE.columns = [
+            c + "_code" if c in self.attrlist else c for c in VALUE.columns
+        ]
         VALUE.rename(columns={"$_code": "value"}, inplace=True)
-        if self.header == "name":
+        if self.name_or_id == "name":
             VALUE = self.rename_japanese(VALUE)
             VALUE.rename(columns={"value": "値"}, inplace=True)
-            
+
         if isinstance(self.TABLE_INF["TITLE"], dict):
             self.TITLE = self.TABLE_INF["TITLE"]["$"]
         else:
             self.TITLE = self.TABLE_INF["TITLE"]
         self.GOV_ORG = self.TABLE_INF["GOV_ORG"]["$"]
         if self.CYCLE != "-":
-            self.StatsDataName = (self.STATISTICS_NAME + "_" + self.TITLE + "_" + self.CYCLE + "_" + self.GOV_ORG).replace(" ", "_")
+            self.StatsDataName = (
+                self.STATISTICS_NAME
+                + "_"
+                + self.TITLE
+                + "_"
+                + self.CYCLE
+                + "_"
+                + self.GOV_ORG
+            ).replace(" ", "_")
         else:
-            self.StatsDataName = (self.STATISTICS_NAME + "_" + self.TITLE + "_" + self.GOV_ORG).replace(" ", "_")
-            
+            self.StatsDataName = (
+                self.STATISTICS_NAME + "_" + self.TITLE + "_" + self.GOV_ORG
+            ).replace(" ", "_")
+
         return VALUE
 
 
 class DataCatalogReader(_eStatReader):
-
     def __init__(
         self,
         api_key,
@@ -788,18 +935,18 @@ class DataCatalogReader(_eStatReader):
         pause=0.1,
         timeout=30,
         session=None,
-        surveyYears=None, 
-        openYears=None, 
-        statsField=None, 
-        statsCode=None, 
-        searchWord=None, 
-        collectArea=None, 
-        dataType=None, 
-        startPosition=None, 
-        catalogId=None, 
-        resourceId=None, 
-        limit=100000, 
-        updatedDate=None, 
+        surveyYears=None,
+        openYears=None,
+        statsField=None,
+        statsCode=None,
+        searchWord=None,
+        collectArea=None,
+        dataType=None,
+        startPosition=None,
+        catalogId=None,
+        resourceId=None,
+        limit=100000,
+        updatedDate=None,
     ):
 
         super().__init__(
@@ -847,7 +994,7 @@ class DataCatalogReader(_eStatReader):
         pdict = {
             "appId": self.api_key,
         }
-        
+
         if isinstance(self.surveyYears, (str, int)):
             pdict.update({"surveyYears": self.surveyYears})
         if isinstance(self.surveyYears, (str, int)):
@@ -874,7 +1021,7 @@ class DataCatalogReader(_eStatReader):
             pdict.update({"resourceId": self.resourceId})
         if isinstance(self.updatedDate, (str, int)):
             pdict.update({"updatedDate": self.updatedDate})
-        
+
         return pdict
 
     def read(self):
@@ -887,21 +1034,41 @@ class DataCatalogReader(_eStatReader):
     def _read_one_data(self, url, params):
         """read one data from specified URL"""
         out = self._get_response(url, params=params).json()
-        
+
         self.STATUS = out["GET_DATA_CATALOG"]["RESULT"]["STATUS"]
         self.ERROR_MSG = out["GET_DATA_CATALOG"]["RESULT"]["ERROR_MSG"]
         self.DATE = out["GET_DATA_CATALOG"]["RESULT"]["DATE"]
         self.LANG = out["GET_DATA_CATALOG"]["PARAMETER"]["LANG"]
         self.DATA_FORMAT = out["GET_DATA_CATALOG"]["PARAMETER"]["DATA_FORMAT"]
         self.NUMBER = out["GET_DATA_CATALOG"]["DATA_CATALOG_LIST_INF"]["NUMBER"]
-        self.FROM_NUMBER = out["GET_DATA_CATALOG"]["DATA_CATALOG_LIST_INF"]["RESULT_INF"]["FROM_NUMBER"]
-        self.TO_NUMBER = out["GET_DATA_CATALOG"]["DATA_CATALOG_LIST_INF"]["RESULT_INF"]["TO_NUMBER"]
-        if "NEXT_KEY" in out["GET_DATA_CATALOG"]["DATA_CATALOG_LIST_INF"]["RESULT_INF"].keys():
-            self.NEXT_KEY = out["GET_DATA_CATALOG"]["DATA_CATALOG_LIST_INF"]["RESULT_INF"]["NEXT_KEY"]
+        self.FROM_NUMBER = out["GET_DATA_CATALOG"]["DATA_CATALOG_LIST_INF"][
+            "RESULT_INF"
+        ]["FROM_NUMBER"]
+        self.TO_NUMBER = out["GET_DATA_CATALOG"]["DATA_CATALOG_LIST_INF"]["RESULT_INF"][
+            "TO_NUMBER"
+        ]
+        if (
+            "NEXT_KEY"
+            in out["GET_DATA_CATALOG"]["DATA_CATALOG_LIST_INF"]["RESULT_INF"].keys()
+        ):
+            self.NEXT_KEY = out["GET_DATA_CATALOG"]["DATA_CATALOG_LIST_INF"][
+                "RESULT_INF"
+            ]["NEXT_KEY"]
 
-        DATA_CATALOG_INF = pd.json_normalize(out, record_path=["GET_DATA_CATALOG", "DATA_CATALOG_LIST_INF", "DATA_CATALOG_INF"], sep="_")
-        DATA_CATALOG_INF.columns = list(map(lambda x: x.replace("@", "").rstrip("_$"), DATA_CATALOG_INF.columns.values.tolist()))
+        DATA_CATALOG_INF = pd.json_normalize(
+            out,
+            record_path=[
+                "GET_DATA_CATALOG",
+                "DATA_CATALOG_LIST_INF",
+                "DATA_CATALOG_INF",
+            ],
+            sep="_",
+        )
+        DATA_CATALOG_INF.columns = list(
+            map(
+                lambda x: x.replace("@", "").rstrip("_$"),
+                DATA_CATALOG_INF.columns.values.tolist(),
+            )
+        )
 
         return DATA_CATALOG_INF
-
-
